==> hp300_1.0.tar: hp300/examples/concepts/layout2.ex <==
#! /usr/lib/veetest/veetest -d /usr/lib/veetest -r
(revision "A.00.00")
(date "Tue 02/Apr/1991")
(component 0 "Context"
 (name "Layout 2 Example")
 (interface
 )
 (implementation
  (trigMode deg)
  (locked no)
  (component 0 "ShiftRegister"
   (name "Shift Register")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
    (output 1
     (type data)
     (name "Current")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "1 Prev")
     (lock name constraints)
     (optional yes)
    )
    (output 3
     (type data)
     (name "2 Prev")
     (lock constraints)
     (optional yes)
    )
    (output 4
     (type data)
     (name "3 Prev")
     (lock constraints)
     (optional yes)
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (origin 390 348)
     (extent 140 76)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 1 "Formula"
   (name " + ")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "X")
     (lock name constraints)
    )
    (input 2
     (type data)
     (name "Y")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "X+Y")
   )
   (views
    (icon
     (origin 557 353)
     (extent 47 27)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 2 "Formula"
   (name " + ")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "X")
     (lock name constraints)
    )
    (input 2
     (type data)
     (name "Y")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "X+Y")
   )
   (views
    (icon
     (origin 557 394)
     (extent 46 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 3 "Note"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 4 5
     This example is provided as an
     illustration "as is", and Hewlett-Packard
     Company makes no warranty of any kind
     with regard to this example.
    )
   )
   (views
    (icon
     (extent 181 0)
    )
    (detail
     (origin 22 469)
     (extent 397 82)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 4 "ShiftRegister"
   (name "Shift Register")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
    (output 1
     (type data)
     (name "Current")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "1 Prev")
     (lock name constraints)
     (optional yes)
    )
    (output 3
     (type data)
     (name "2 Prev")
     (lock constraints)
     (optional yes)
    )
    (output 4
     (type data)
     (name "3 Prev")
     (lock constraints)
     (optional yes)
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (origin 392 268)
     (extent 136 45)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 5 "Formula"
   (name " + ")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "X")
     (lock name constraints)
    )
    (input 2
     (type data)
     (name "Y")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "X+Y")
   )
   (views
    (icon
     (origin 567 308)
     (extent 46 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 6 "Formula"
   (name " + ")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "X")
     (lock name constraints)
    )
    (input 2
     (type data)
     (name "Y")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "X+Y")
   )
   (views
    (icon
     (origin 567 267)
     (extent 47 27)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 7 "FromArray"
   (name "Get Values")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Ary")
     (tag "Ary")
    )
    (output 1
     (type data)
     (name "SubAry")
     (tag "Result")
     (lock constraints)
    )
    (output 2
     (type data)
     (name "Type")
     (tag "Type")
     (lock constraints)
    )
    (output 3
     (type data)
     (name "NumDims")
     (tag "NumDims")
     (lock constraints)
    )
    (output 4
     (type data)
     (name "DimSizes")
     (tag "DimSizes")
     (lock constraints)
    )
    (output 5
     (type data)
     (name "TotSize")
     (tag "TotSize")
     (lock constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr 1 "Ary[3,4:6,*]")
   )
   (views
    (icon
     (origin 395 88)
     (extent 110 64)
     (iconImage unbuild.icon)
    )
    (detail
     (origin 352 120)
     (extent 147 160)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 8 "FromArray"
   (name "Get Values")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Ary")
     (tag "Ary")
    )
    (output 1
     (type data)
     (name "SubAry")
     (tag "Result")
     (lock constraints)
    )
    (output 2
     (type data)
     (name "Type")
     (tag "Type")
     (lock constraints)
    )
    (output 3
     (type data)
     (name "NumDims")
     (tag "NumDims")
     (lock constraints)
    )
    (output 4
     (type data)
     (name "DimSizes")
     (tag "DimSizes")
     (lock constraints)
    )
    (output 5
     (type data)
     (name "TotSize")
     (tag "TotSize")
     (lock constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr 1 "Ary[3,4:6,*]")
   )
   (views
    (icon
     (origin 395 168)
     (extent 110 64)
     (iconImage unbuild.icon)
    )
    (detail
     (origin 352 200)
     (extent 147 160)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 9 "Note"
   (name "Overview of Layout1 example")
   (interface
   )
   (implementation
    (component text 21 5
     Pupose: Demonstrate the effect of
     alignment and sizing on layout.
     
     Required user input: none
     
     Explanation:
     The top pairs of Get Values objects
     and the If/Then objects shows how
     important alignment can be.  By
     aligning the objects the lines
     become both short and straight.  
     
     The bottom pairs of Shift Register 
     and + objects demonstates how 
     changing the size an object can
     affect line layout.  By sizing
     the Shift Register so the output pin
     spacing matches the spacing of the
     + boxes, the lines become shorter 
     and straighter.
     
    )
   )
   (views
    (icon
     (extent 253 0)
    )
    (detail
     (origin 13 116)
     (extent 354 269)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 10 "IfThenElse"
   (name "If/Then")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (input 2
     (type data)
     (name "B")
     (optional yes)
    )
    (input 3
     (type data)
     (name "C")
     (optional yes)
    )
    (input 4
     (type data)
     (name "D")
     (optional yes)
    )
    (input 5
     (type data)
     (name "E")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Then")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "Else")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr "0<=A AND A<10")
   )
   (views
    (icon
     (origin 541 173)
     (extent 78 54)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 11 "IfThenElse"
   (name "If/Then")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (input 2
     (type data)
     (name "B")
     (optional yes)
    )
    (input 3
     (type data)
     (name "C")
     (optional yes)
    )
    (input 4
     (type data)
     (name "D")
     (optional yes)
    )
    (input 5
     (type data)
     (name "E")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Then")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "Else")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr "0<=A AND A<10")
   )
   (views
    (icon
     (origin 541 103)
     (extent 78 54)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (configuration
   (connect D0:1 D1:1)
   (connect D0:2 D1:2)
   (connect D0:3 D2:1)
   (connect D0:4 D2:2)
   (connect D4:3 D5:1)
   (connect D4:4 D5:2)
   (connect D4:1 D6:1)
   (connect D4:2 D6:2)
   (connect D8:1 D10:1)
   (connect D8:2 D10:2)
   (connect D8:3 D10:3)
   (connect D8:4 D10:4)
   (connect D8:5 D10:5)
   (connect D7:1 D11:1)
   (connect D7:2 D11:2)
   (connect D7:3 D11:3)
   (connect D7:4 D11:4)
   (connect D7:5 D11:5)
  )
 )
 (views
  (detail
   (origin 0 67)
   (extent 1012 721)
   (configuration
    (connect D0:1 D1:1
     (Point 532 356)
     (Point 554 356)
    )
    (connect D0:2 D1:2
     (Point 532 376)
     (Point 554 376)
    )
    (connect D0:3 D2:1
     (Point 532 396)
     (Point 554 396)
    )
    (connect D0:4 D2:2
     (Point 532 416)
     (Point 554 416)
    )
    (connect D4:3 D5:1
     (Point 530 290)
     (Point 540 290)
     (Point 540 300)
     (Point 550 300)
     (Point 550 310)
     (Point 564 310)
    )
    (connect D4:4 D5:2
     (Point 530 300)
     (Point 540 300)
     (Point 540 330)
     (Point 564 330)
    )
    (connect D4:1 D6:1
     (Point 530 270)
     (Point 564 270)
    )
    (connect D4:2 D6:2
     (Point 530 280)
     (Point 550 280)
     (Point 550 290)
     (Point 564 290)
    )
    (connect D8:1 D10:1
     (Point 507 180)
     (Point 538 180)
    )
    (connect D8:2 D10:2
     (Point 507 190)
     (Point 538 190)
    )
    (connect D8:3 D10:3
     (Point 507 200)
     (Point 538 200)
    )
    (connect D8:4 D10:4
     (Point 507 210)
     (Point 538 210)
    )
    (connect D8:5 D10:5
     (Point 507 220)
     (Point 538 220)
    )
    (connect D7:1 D11:1
     (Point 507 100)
     (Point 530 100)
     (Point 530 110)
     (Point 538 110)
    )
    (connect D7:2 D11:2
     (Point 507 110)
     (Point 530 110)
     (Point 530 120)
     (Point 538 120)
    )
    (connect D7:3 D11:3
     (Point 507 120)
     (Point 520 120)
     (Point 520 130)
     (Point 538 130)
    )
    (connect D7:4 D11:4
     (Point 507 130)
     (Point 520 130)
     (Point 520 140)
     (Point 538 140)
    )
    (connect D7:5 D11:5
     (Point 507 140)
     (Point 520 140)
     (Point 520 150)
     (Point 538 150)
    )
   )
  )
  (active detail)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
 )
)

==> hp300_1.4.tar: hp300/examples/concepts/layout2.ex <==
#! /usr/lib/veetest/veetest -r
(revision "A.00.01")
(date "Mon 09/Sep/1991")
(component 0 "Context"
 (name "Layout 2 Example")
 (interface
 )
 (implementation
  (trigMode deg)
  (locked no)
  (component 0 "ShiftRegister"
   (name "Shift Register")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
    (output 1
     (type data)
     (name "Current")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "1 Prev")
     (lock name constraints)
     (optional yes)
    )
    (output 3
     (type data)
     (name "2 Prev")
     (lock constraints)
     (optional yes)
    )
    (output 4
     (type data)
     (name "3 Prev")
     (lock constraints)
     (optional yes)
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (origin 490 418)
     (extent 140 76)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 1 "Formula"
   (name " + ")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "X")
     (lock name constraints)
    )
    (input 2
     (type data)
     (name "Y")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "X+Y")
   )
   (views
    (icon
     (origin 657 423)
     (extent 47 27)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 2 "Formula"
   (name " + ")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "X")
     (lock name constraints)
    )
    (input 2
     (type data)
     (name "Y")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "X+Y")
   )
   (views
    (icon
     (origin 657 464)
     (extent 46 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 3 "ShiftRegister"
   (name "Shift Register")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
    (output 1
     (type data)
     (name "Current")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "1 Prev")
     (lock name constraints)
     (optional yes)
    )
    (output 3
     (type data)
     (name "2 Prev")
     (lock constraints)
     (optional yes)
    )
    (output 4
     (type data)
     (name "3 Prev")
     (lock constraints)
     (optional yes)
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (origin 492 338)
     (extent 136 45)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 4 "Formula"
   (name " + ")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "X")
     (lock name constraints)
    )
    (input 2
     (type data)
     (name "Y")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "X+Y")
   )
   (views
    (icon
     (origin 667 378)
     (extent 46 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 5 "Formula"
   (name " + ")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "X")
     (lock name constraints)
    )
    (input 2
     (type data)
     (name "Y")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "X+Y")
   )
   (views
    (icon
     (origin 667 337)
     (extent 47 27)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 6 "IfThenElse"
   (name "If/Then")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (input 2
     (type data)
     (name "B")
     (optional yes)
    )
    (input 3
     (type data)
     (name "C")
     (optional yes)
    )
    (input 4
     (type data)
     (name "D")
     (optional yes)
    )
    (input 5
     (type data)
     (name "E")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Then")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "Else")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr "0<=A AND A<10")
   )
   (views
    (icon
     (origin 641 243)
     (extent 78 54)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 7 "IfThenElse"
   (name "If/Then")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (input 2
     (type data)
     (name "B")
     (optional yes)
    )
    (input 3
     (type data)
     (name "C")
     (optional yes)
    )
    (input 4
     (type data)
     (name "D")
     (optional yes)
    )
    (input 5
     (type data)
     (name "E")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Then")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "Else")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr "0<=A AND A<10")
   )
   (views
    (icon
     (origin 641 173)
     (extent 78 54)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 8 "Constant"
   (name "0")
   (subType "Integer")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Int32")
     (lock name constraints)
    )
   )
   (implementation
    (component value Int32
     (name "0")
     (numDims 1)
     (size 1)
     (data
      [ 0 ]
     )
    )
    (component autoTrigger off)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Int32
     (datum 0)
    )
   )
   (views
    (icon
     (origin 407 298)
     (extent 46 25)
    )
    (detail
     (origin 749 210)
     (extent 162 40)
     (showFormat int)
    )
    (active icon)
   )
  )
  (component 9 "Note"
   (name "Overview of Layout1 example")
   (interface
   )
   (implementation
    (component text 21 5
     Purpose: Demonstrate the effect of
     alignment and sizing on layout.
     
     Required user input: none
     
     Explanation:
     The top pairs of Get Values objects
     and the If/Then objects shows how
     important alignment can be.  By
     aligning the objects the lines
     become both short and straight.  
     
     The bottom pairs of Shift Register 
     and + objects demonstates how 
     changing the size an object can
     affect line layout.  By sizing
     the Shift Register so the output pin
     spacing matches the spacing of the
     + boxes, the lines become shorter 
     and straighter.
     
    )
   )
   (views
    (icon
     (extent 253 0)
    )
    (detail
     (origin 33 176)
     (extent 354 269)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 10 "Note"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 4 5
     This example is provided as an
     illustration "as is", and Hewlett-Packard
     Company makes no warranty of any kind
     with regard to this example.
    )
   )
   (views
    (icon
     (extent 181 0)
    )
    (detail
     (origin 22 509)
     (extent 397 82)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 11 "FromArray"
   (name "Get Values")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Ary")
     (tag "Ary")
    )
    (output 1
     (type data)
     (name "SubAry")
     (tag "Result")
     (lock constraints)
    )
    (output 2
     (type data)
     (name "Type")
     (tag "Type")
     (lock constraints)
    )
    (output 3
     (type data)
     (name "NumDims")
     (tag "NumDims")
     (lock constraints)
    )
    (output 4
     (type data)
     (name "DimSizes")
     (tag "DimSizes")
     (lock constraints)
    )
    (output 5
     (type data)
     (name "TotSize")
     (tag "TotSize")
     (lock constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr 1 "Ary")
   )
   (views
    (icon
     (origin 495 158)
     (extent 110 64)
     (iconImage "unbuild.icon")
    )
    (detail
     (origin 452 110)
     (extent 147 160)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 12 "FromArray"
   (name "Get Values")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Ary")
     (tag "Ary")
    )
    (output 1
     (type data)
     (name "SubAry")
     (tag "Result")
     (lock constraints)
    )
    (output 2
     (type data)
     (name "Type")
     (tag "Type")
     (lock constraints)
    )
    (output 3
     (type data)
     (name "NumDims")
     (tag "NumDims")
     (lock constraints)
    )
    (output 4
     (type data)
     (name "DimSizes")
     (tag "DimSizes")
     (lock constraints)
    )
    (output 5
     (type data)
     (name "TotSize")
     (tag "TotSize")
     (lock constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr 1 "Ary")
   )
   (views
    (icon
     (origin 495 238)
     (extent 110 64)
     (iconImage "unbuild.icon")
    )
    (detail
     (origin 452 190)
     (extent 147 160)
    )
    (terminals on)
    (active icon)
   )
  )
  (configuration
   (connect D8:1 D0:1)
   (connect D0:1 D1:1)
   (connect D0:2 D1:2)
   (connect D0:3 D2:1)
   (connect D0:4 D2:2)
   (connect D8:1 D3:1)
   (connect D3:3 D4:1)
   (connect D3:4 D4:2)
   (connect D3:1 D5:1)
   (connect D3:2 D5:2)
   (connect D12:1 D6:1)
   (connect D12:2 D6:2)
   (connect D12:3 D6:3)
   (connect D12:4 D6:4)
   (connect D12:5 D6:5)
   (connect D11:1 D7:1)
   (connect D11:2 D7:2)
   (connect D11:3 D7:3)
   (connect D11:4 D7:4)
   (connect D11:5 D7:5)
   (connect D8:1 D11:1)
   (connect D8:1 D12:1)
  )
 )
 (views
  (detail
   (origin 0 67)
   (extent 1004 664)
   (configuration
    (connect D8:1 D0:1
     (Point 455 310)
     (Point 470 310)
     (Point 470 456)
     (Point 487 456)
    )
    (connect D0:1 D1:1
     (Point 632 426)
     (Point 654 426)
    )
    (connect D0:2 D1:2
     (Point 632 446)
     (Point 654 446)
    )
    (connect D0:3 D2:1
     (Point 632 466)
     (Point 654 466)
    )
    (connect D0:4 D2:2
     (Point 632 486)
     (Point 654 486)
    )
    (connect D8:1 D3:1
     (Point 455 310)
     (Point 470 310)
     (Point 470 360)
     (Point 489 360)
    )
    (connect D3:3 D4:1
     (Point 630 360)
     (Point 640 360)
     (Point 640 370)
     (Point 650 370)
     (Point 650 380)
     (Point 664 380)
    )
    (connect D3:4 D4:2
     (Point 630 370)
     (Point 640 370)
     (Point 640 400)
     (Point 664 400)
    )
    (connect D3:1 D5:1
     (Point 630 340)
     (Point 664 340)
    )
    (connect D3:2 D5:2
     (Point 630 350)
     (Point 650 350)
     (Point 650 360)
     (Point 664 360)
    )
    (connect D12:1 D6:1
     (Point 607 250)
     (Point 622 250)
     (Point 622 250)
     (Point 638 250)
    )
    (connect D12:2 D6:2
     (Point 607 260)
     (Point 622 260)
     (Point 622 260)
     (Point 638 260)
    )
    (connect D12:3 D6:3
     (Point 607 270)
     (Point 622 270)
     (Point 622 270)
     (Point 638 270)
    )
    (connect D12:4 D6:4
     (Point 607 280)
     (Point 622 280)
     (Point 622 280)
     (Point 638 280)
    )
    (connect D12:5 D6:5
     (Point 607 290)
     (Point 622 290)
     (Point 622 290)
     (Point 638 290)
    )
    (connect D11:1 D7:1
     (Point 607 170)
     (Point 630 170)
     (Point 630 180)
     (Point 638 180)
    )
    (connect D11:2 D7:2
     (Point 607 180)
     (Point 630 180)
     (Point 630 190)
     (Point 638 190)
    )
    (connect D11:3 D7:3
     (Point 607 190)
     (Point 620 190)
     (Point 620 200)
     (Point 638 200)
    )
    (connect D11:4 D7:4
     (Point 607 200)
     (Point 620 200)
     (Point 620 210)
     (Point 638 210)
    )
    (connect D11:5 D7:5
     (Point 607 210)
     (Point 620 210)
     (Point 620 220)
     (Point 638 220)
    )
    (connect D8:1 D11:1
     (Point 455 310)
     (Point 470 310)
     (Point 470 190)
     (Point 492 190)
    )
    (connect D8:1 D12:1
     (Point 455 310)
     (Point 470 310)
     (Point 470 270)
     (Point 492 270)
    )
   )
  )
  (active detail)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
 )
)
